==> bytedesk_kefu-1.3.1.tar.gz: lib/blocs/thread_bloc/thread_event.dart <==
import 'package:equatable/equatable.dart';
import 'package:meta/meta.dart';

@immutable
abstract class ThreadEvent extends Equatable {
  const ThreadEvent();

  @override
  List<Object> get props => [];
}

// class InitThreadEvent extends ThreadEvent {}

class RefreshThreadEvent extends ThreadEvent {}

class RefreshHistoryThreadEvent extends ThreadEvent {
  final int? page;
  final int? size;
  //
  RefreshHistoryThreadEvent({@required this.page, @required this.size})
      : super();
}

class RefreshVisitorThreadEvent extends ThreadEvent {
  final int? page;
  final int? size;
  //
  RefreshVisitorThreadEvent({@required this.page, @required this.size})
      : super();
}

class RefreshVisitorThreadAllEvent extends ThreadEvent {
  //
  RefreshVisitorThreadAllEvent() : super();
}

class UpdateThreadEvent extends ThreadEvent {
  final String? tid;

  UpdateThreadEvent({@required this.tid})
      : assert(tid != null),
        super();
}

class DeleteThreadEvent extends ThreadEvent {
  final String? tid;

  DeleteThreadEvent({@required this.tid})
      : assert(tid != null),
        super();
}

// 请求客服会话
class RequestThreadEvent extends ThreadEvent {
  final String? wid;
  final String? type;
  final String? aid;
  final bool? isV2Robot;

  RequestThreadEvent(
      {@required this.wid, @required this.type, @required this.aid, @required this.isV2Robot})
      : super();
}

// 请求人工客服，不管此工作组是否设置为默认机器人，只要有人工客服在线，则可以直接对接人工
class RequestAgentEvent extends ThreadEvent {
  final String? wid;
  final String? type;
  final String? aid;

  RequestAgentEvent(
      {@required this.wid, @required this.type, @required this.aid})
      : super();
}

class RequestContactThreadEvent extends ThreadEvent {
  final String? cid;

  RequestContactThreadEvent({@required this.cid}) : super();
}

class RequestGroupThreadEvent extends ThreadEvent {
  final String? gid;

  RequestGroupThreadEvent({@required this.gid}) : super();
}

class MarkTopThreadEvent extends ThreadEvent {
  final String? tid;

  MarkTopThreadEvent({@required this.tid}) : super();
}

class UnMarkTopThreadEvent extends ThreadEvent {
  final String? tid;

  UnMarkTopThreadEvent({@required this.tid}) : super();
}

class MarkNodisturbThreadEvent extends ThreadEvent {
  final String? tid;

  MarkNodisturbThreadEvent({@required this.tid}) : super();
}

class UnMarkNodisturbThreadEvent extends ThreadEvent {
  final String? tid;

  UnMarkNodisturbThreadEvent({@required this.tid}) : super();
}

class MarkUnreadThreadEvent extends ThreadEvent {
  final String? tid;

  MarkUnreadThreadEvent({@required this.tid}) : super();
}

class UnMarkUnreadThreadEvent extends ThreadEvent {
  final String? tid;

  UnMarkUnreadThreadEvent({@required this.tid}) : super();
}

==> bytedesk_kefu-1.5.3.tar.gz: lib/blocs/thread_bloc/thread_event.dart <==
import 'package:equatable/equatable.dart';
import 'package:meta/meta.dart';

@immutable
abstract class ThreadEvent extends Equatable {
  const ThreadEvent();

  @override
  List<Object> get props => [];
}

// class InitThreadEvent extends ThreadEvent {}

class RefreshThreadEvent extends ThreadEvent {}

class RefreshHistoryThreadEvent extends ThreadEvent {
  final int? page;
  final int? size;
  //
  const RefreshHistoryThreadEvent({@required this.page, @required this.size})
      : super();
}

class RefreshVisitorThreadEvent extends ThreadEvent {
  final int? page;
  final int? size;
  //
  const RefreshVisitorThreadEvent({@required this.page, @required this.size})
      : super();
}

class RefreshVisitorThreadAllEvent extends ThreadEvent {
  //
  const RefreshVisitorThreadAllEvent() : super();
}

class UpdateThreadEvent extends ThreadEvent {
  final String? tid;

  const UpdateThreadEvent({@required this.tid})
      : assert(tid != null),
        super();
}

class DeleteThreadEvent extends ThreadEvent {
  final String? tid;

  const DeleteThreadEvent({@required this.tid})
      : assert(tid != null),
        super();
}

// 请求客服会话
class RequestThreadEvent extends ThreadEvent {
  final String? wid;
  final String? type;
  final String? aid;
  final bool? isV2Robot;

  const RequestThreadEvent(
      {@required this.wid, @required this.type, @required this.aid, @required this.isV2Robot})
      : super();
}

// 请求人工客服，不管此工作组是否设置为默认机器人，只要有人工客服在线，则可以直接对接人工
class RequestAgentEvent extends ThreadEvent {
  final String? wid;
  final String? type;
  final String? aid;

  const RequestAgentEvent(
      {@required this.wid, @required this.type, @required this.aid})
      : super();
}

class RequestContactThreadEvent extends ThreadEvent {
  final String? cid;

  const RequestContactThreadEvent({@required this.cid}) : super();
}

class RequestGroupThreadEvent extends ThreadEvent {
  final String? gid;

  const RequestGroupThreadEvent({@required this.gid}) : super();
}

class MarkTopThreadEvent extends ThreadEvent {
  final String? tid;

  const MarkTopThreadEvent({@required this.tid}) : super();
}

class UnMarkTopThreadEvent extends ThreadEvent {
  final String? tid;

  const UnMarkTopThreadEvent({@required this.tid}) : super();
}

class MarkNodisturbThreadEvent extends ThreadEvent {
  final String? tid;

  const MarkNodisturbThreadEvent({@required this.tid}) : super();
}

class UnMarkNodisturbThreadEvent extends ThreadEvent {
  final String? tid;

  const UnMarkNodisturbThreadEvent({@required this.tid}) : super();
}

class MarkUnreadThreadEvent extends ThreadEvent {
  final String? tid;

  const MarkUnreadThreadEvent({@required this.tid}) : super();
}

class UnMarkUnreadThreadEvent extends ThreadEvent {
  final String? tid;

  const UnMarkUnreadThreadEvent({@required this.tid}) : super();
}
